==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaRealOcenaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class DiagnozaRealOcenaKey extends GenericDPSObject {
    /**
     * DIAGNOZA_REAL_OCENA.DIAGNOZA_REAL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long diagnozaRealId;

    /**
     * DIAGNOZA_REAL_OCENA.OCENA_OSOBY_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ocenaOsobyId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_REAL_OCENA.DIAGNOZA_REAL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDiagnozaRealId() {
        return diagnozaRealId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DIAGNOZA_REAL_OCENA.DIAGNOZA_REAL_ID
     *
     * @param diagnozaRealId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDiagnozaRealId(Long diagnozaRealId) {
        this.diagnozaRealId = diagnozaRealId;
    }

    /**
     * @return DIAGNOZA_REAL_OCENA.OCENA_OSOBY_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOcenaOsobyId() {
        return ocenaOsobyId;
    }

    /**
     * DIAGNOZA_REAL_OCENA.OCENA_OSOBY_ID
     *
     * @param ocenaOsobyId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOcenaOsobyId(Long ocenaOsobyId) {
        this.ocenaOsobyId = ocenaOsobyId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaRealOcenaKey other = (DiagnozaRealOcenaKey) that;
        return (this.getDiagnozaRealId() == null ? other.getDiagnozaRealId() == null : this.getDiagnozaRealId().equals(other.getDiagnozaRealId()))
            && (this.getOcenaOsobyId() == null ? other.getOcenaOsobyId() == null : this.getOcenaOsobyId().equals(other.getOcenaOsobyId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDiagnozaRealId() == null) ? 0 : getDiagnozaRealId().hashCode());
        result = prime * result + ((getOcenaOsobyId() == null) ? 0 : getOcenaOsobyId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", diagnozaRealId=").append(diagnozaRealId);
        sb.append(", ocenaOsobyId=").append(ocenaOsobyId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaRealOcenaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class DiagnozaRealOcenaKey extends GenericDPSObject {
    /**
     * DIAGNOZA_REAL_OCENA.DIAGNOZA_REAL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long diagnozaRealId;

    /**
     * DIAGNOZA_REAL_OCENA.OCENA_OSOBY_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ocenaOsobyId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_REAL_OCENA.DIAGNOZA_REAL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDiagnozaRealId() {
        return diagnozaRealId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DIAGNOZA_REAL_OCENA.DIAGNOZA_REAL_ID
     *
     * @param diagnozaRealId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDiagnozaRealId(Long diagnozaRealId) {
        this.diagnozaRealId = diagnozaRealId;
    }

    /**
     * @return DIAGNOZA_REAL_OCENA.OCENA_OSOBY_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOcenaOsobyId() {
        return ocenaOsobyId;
    }

    /**
     * DIAGNOZA_REAL_OCENA.OCENA_OSOBY_ID
     *
     * @param ocenaOsobyId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOcenaOsobyId(Long ocenaOsobyId) {
        this.ocenaOsobyId = ocenaOsobyId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaRealOcenaKey other = (DiagnozaRealOcenaKey) that;
        return (this.getDiagnozaRealId() == null ? other.getDiagnozaRealId() == null : this.getDiagnozaRealId().equals(other.getDiagnozaRealId()))
            && (this.getOcenaOsobyId() == null ? other.getOcenaOsobyId() == null : this.getOcenaOsobyId().equals(other.getOcenaOsobyId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDiagnozaRealId() == null) ? 0 : getDiagnozaRealId().hashCode());
        result = prime * result + ((getOcenaOsobyId() == null) ? 0 : getOcenaOsobyId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", diagnozaRealId=").append(diagnozaRealId);
        sb.append(", ocenaOsobyId=").append(ocenaOsobyId);
        sb.append("]");
        return sb.toString();
    }
}
